//+------------------------------------------------------------------+
//|                                            mov ave crossover.mq4 |
//|                        Copyright 2012, MetaQuotes Software Corp. |
//|                                        http://www.metaquotes.net |
//+------------------------------------------------------------------+
#property copyright "Copyright 2012, Doug Snyder"
#define MAGICMA 20050610

extern double Lots               = 0.1;
extern double MaximumRisk        = 0.02;
extern double DecreaseFactor     = 3;
extern double MovingPeriod       = 20;
extern double MovingShift        = 6;
extern double Kperiod           = 14;
extern double Dperiod           = 3;
extern double Slowing            = 3;

//+------------------------------------------------------------------+
//| Calculate open positions                                         |
//+------------------------------------------------------------------+
int CalculateCurrentOrders(string symbol)
  {
   int buys=0,sells=0;
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false) break;
      if(OrderSymbol()==Symbol() && OrderMagicNumber()==MAGICMA)
        {
         if(OrderType()==OP_BUY)  buys++;
         if(OrderType()==OP_SELL) sells++;
        }
     }
//---- return orders volume
   if(buys>0) return(buys);
   else       return(-sells);
  }
//+------------------------------------------------------------------+
//| Calculate optimal lot size                                       |
//+------------------------------------------------------------------+
double LotsOptimized()
  {
   double lot=Lots;
   int    orders=HistoryTotal();     // history orders total
   int    losses=0;                  // number of losses orders without a break
//---- select lot size
   lot=NormalizeDouble(AccountFreeMargin()*MaximumRisk/1000.0,1);
//---- calcuulate number of losses orders without a break
   if(DecreaseFactor>0)
     {
      for(int i=orders-1;i>=0;i--)
        {
         if(OrderSelect(i,SELECT_BY_POS,MODE_HISTORY)==false) { Print("Error in history!"); break; }
         if(OrderSymbol()!=Symbol() || OrderType()>OP_SELL) continue;
         //----
         if(OrderProfit()>0) break;
         if(OrderProfit()<0) losses++;
        }
      if(losses>1) lot=NormalizeDouble(lot-lot*losses/DecreaseFactor,1);
     }
//---- return lot size
   if(lot<0.1) lot=0.1;
   return(lot);
  }
//+------------------------------------------------------------------+
//| Check for open order conditions                                  |
//+------------------------------------------------------------------+
void CheckForOpen()
  {
   int    res;
   double Ubands, Lbands, percentB;
   double ma, MFI;
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
   RefreshRates();
//---- get Indicators
   Ubands=iBands(NULL,0,20,2,0,PRICE_CLOSE,MODE_UPPER,0);
   Lbands=iBands(NULL,0,20,2,0,PRICE_CLOSE,MODE_LOWER,0);
   ma=iMA(NULL,0,MovingPeriod,0,MODE_SMA,PRICE_CLOSE,0);
   percentB=(PRICE_CLOSE-Lbands)/(Ubands-Lbands);   
   MFI=iMFI(NULL,0,10,0);
//---- sell conditions
   if (percentB<(1/5) && MFI<25)
      {
      res=OrderSend(Symbol(),OP_SELL,LotsOptimized(),Bid,5,Bid+300*Point,Bid-600*Point,"",MAGICMA,0,Red);  
      return;
      }
//---- buy conditions
   if(percentB>(4/5) && MFI>75)  
     {
      res=OrderSend(Symbol(),OP_BUY,LotsOptimized(),Ask,5,Ask-300*Point,Ask+600*Point,"",MAGICMA,0,Blue);
      return;
     }
//----
  }
//+------------------------------------------------------------------+
//| Check for close order conditions                                 |
//+------------------------------------------------------------------+
void CheckForClose()
  {
  double ma,maPeriodDoubled,Stochastic,StoSignal;
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
   RefreshRates();
//---- get Moving Average 
   ma=iMA(NULL,0,MovingPeriod,0,MODE_SMA,PRICE_CLOSE,0);
   maPeriodDoubled=iMA(NULL,0,MovingPeriod*2,0,MODE_SMA,PRICE_CLOSE,0);
   Stochastic=iStochastic(NULL,0,Kperiod,Dperiod,Slowing,MODE_SMA,1,MODE_MAIN,0);
   StoSignal=iStochastic(NULL,0,Kperiod,Dperiod,Slowing,MODE_SMA,1,MODE_SIGNAL,0);
   
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false)        break;
      if(OrderMagicNumber()!=MAGICMA || OrderSymbol()!=Symbol()) continue;
      //---- check order type 
      if(OrderType()==OP_BUY)
        {
         //if(Close[1]<ma) OrderClose(OrderTicket(),OrderLots(),Bid,3,White);
         break;
        }
      if(OrderType()==OP_SELL)
        {
         //if(Close[1]>ma) OrderClose(OrderTicket(),OrderLots(),Ask,3,White);
         break;
        }
     }
//----
  }
//+------------------------------------------------------------------+
//| Start function                                                   |
//+------------------------------------------------------------------+
void start()
  {
//---- check for history and trading
   if(Bars<100 || IsTradeAllowed()==false) return;
//---- calculate open orders by current symbol   
   if(CalculateCurrentOrders(Symbol())==0) CheckForOpen();
   else                                    CheckForClose();
//----
  }
//+------------------------------------------------------------------+

